Value

pub enum Value {
Show 25 variants ScalarNull(EmptyScalar), ScalarBoolean(bool), ScalarInt8(i32), ScalarInt16(i32), ScalarInt32(i32), ScalarInt64(i64), ScalarInt128(Vec<u8>), ScalarUint8(u32), ScalarUint16(u32), ScalarUint32(u32), ScalarUint64(u64), ScalarUint128(Vec<u8>), ScalarFloat16(f32), ScalarFloat32(f32), ScalarFloat64(f64), ScalarDecimal64(Decimal64Scalar), ScalarDecimal128(Decimal128Scalar), ScalarTimestamp(TimestampScalar), ScalarDate32(i32), ScalarDate64(i64), ScalarInterval(IntervalScalar), ScalarUtf8(String), ScalarBinary(Vec<u8>), ScalarStruct(StructScalar), ScalarList(ListScalar),
}

Variants



ScalarNull(EmptyScalar)



ScalarBoolean(bool)



ScalarInt8(i32)



ScalarInt16(i32)



ScalarInt32(i32)



ScalarInt64(i64)



ScalarInt128(Vec<u8>)



ScalarUint8(u32)



ScalarUint16(u32)



ScalarUint32(u32)



ScalarUint64(u64)



ScalarUint128(Vec<u8>)



ScalarFloat16(f32)



ScalarFloat32(f32)



ScalarFloat64(f64)



ScalarDecimal64(Decimal64Scalar)



ScalarDecimal128(Decimal128Scalar)



ScalarTimestamp(TimestampScalar)



ScalarDate32(i32)



ScalarDate64(i64)



ScalarInterval(IntervalScalar)



ScalarUtf8(String)



ScalarBinary(Vec<u8>)



ScalarStruct(StructScalar)



ScalarList(ListScalar)

Implementations

Source

impl Value

pub fn encode(&self, buf: &mut impl BufMut)

Encodes the message to a buffer.

pub fn merge( field: &mut Option<Value>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>

Decodes an instance of the message from a buffer, and merges it into self.

pub fn encoded_len(&self) -> usize

Returns the encoded length of the message without a length delimiter.