#[repr(i32)]pub enum UnaryOperator {
InvalidUnaryOperator = 0,
UnaryIsTrue = 1,
UnaryIsFalse = 2,
UnaryIsNull = 3,
UnaryIsNotNull = 4,
UnaryNegate = 5,
}Variants
InvalidUnaryOperator = 0
UnaryIsTrue = 1
UnaryIsFalse = 2
UnaryIsNull = 3
UnaryIsNotNull = 4
UnaryNegate = 5
Implementations
Sourceimpl UnaryOperator
impl UnaryOperator
Sourceimpl UnaryOperator
impl UnaryOperator
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.