pub struct ResolvedTableFunctionReferenceWithLocation {
pub bound: Option<ResolvedTableFunctionReference>,
pub location: i32,
}Fields
bound: Option<ResolvedTableFunctionReference>location: i32Implementations
Sourceimpl ResolvedTableFunctionReferenceWithLocation
impl ResolvedTableFunctionReferenceWithLocation
Sourcepub fn location(&self) -> LocationRequirement
pub fn location(&self) -> LocationRequirement
Returns the enum value of location, or the default if the field is set to an invalid enum value.
Sourcepub fn set_location(&mut self, value: LocationRequirement)
pub fn set_location(&mut self, value: LocationRequirement)
Sets location to the provided enum value.